@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use Encode;
 
-our $VERSION = "0.07";
+our $VERSION = "0.08";
 
 use TOML::Parser::Tokenizer qw/:constant/;
 use TOML::Parser::Tokenizer::Strict;
@@ -328,5 +328,7 @@ karupanerura E<lt>karupa@cpan.orgE<gt>
 =head1 CONTRIBUTOR
 
 Olivier Mengué E<lt>dolmen@cpan.orgE<gt>
+yowcow E<lt>yowcow@cpan.orgE<gt>
+Syohei YOSHIDA E<lt>syohex@gmail.comE<gt>
 
 =cut
