@@ -54,7 +54,7 @@ sub grammar_regexp {
             sep   => qr{\.},
             end   => qr{\]\]},
         },
-        key            => qr{(?:"(.*?)(?<!(?<!\\)\\)"|\'(.*?)(?<!(?<!\\)\\)\'|([^\s]+))\s*=},
+        key            => qr{(?:"(.*?)(?<!(?<!\\)\\)"|\'(.*?)(?<!(?<!\\)\\)\'|([^\s=]+))\s*=},
         value          => {
             datetime => qr{([0-9]{4}-[0-9]{2}-[0-9]{2}T[0-9]{2}:[0-9]{2}:[0-9]{2}(?:\.[0-9]+)?(?:Z|[-+][0-9]{2}:[0-9]{2}))},
             float    => qr{([-+]?(?:[0-9_]+(?:\.[0-9_]+)?[eE][-+]?[0-9_]+|[0-9_]*\.[0-9_]+))},
@@ -162,7 +162,7 @@ sub _tokenize_value {
         return [TOKEN_BOOLEAN, $1];
     }
     elsif (/\G$grammar_regexp->{value}->{mlstring}/mgc) {
-        warn "[TOKEN] BOOLEAN: $1" if DEBUG;
+        warn "[TOKEN] MULTI LINE STRING: $1" if DEBUG;
         return (
             [TOKEN_MULTI_LINE_STRING_BEGIN],
             $class->_extract_multi_line_string($1),
